<?php

namespace Drupal\campaign_kit\Campaign;

use Drupal\campaign_kit_core\Entity\CampaignDonation;
use Drupal\campaign_kit_core\Entity\CampaignTransaction;

/**
 * Provide extra functions for campaigns.
 *
 * @package Drupal\campaign_kit\Campaign
 */
class CampaignAPI {

  /**
   * Create Campaign function.
   *
   * @param array $values
   *   Array values to create a Campaign entity.
   *
   * @return string
   *   Returns a object.
   */
  public function createCampaign(array $values = []) {
    return 'createCampaign';
  }

  /**
   * Creates a Campaign Donation.
   *
   * @param array $values
   *   Values to create a Campaign Donation entity.
   *
   * @return \Drupal\campaign_kit_core\Entity\CampaignDonation
   *   Returns a Campaign Donation entity.
   */
  public function createCampaignDonation(array $values = []) {
    // Create Campaign Donation entity.
    /* @var $campaignDonation \Drupal\campaign_kit_core\Entity\CampaignDonation */
    $campaignDonation = CampaignDonation::create($values);

    return $campaignDonation;
  }

  /**
   * Creates a Campaign Transaction.
   *
   * @param array $values
   *   Values to create a Campaign entity.
   *
   * @return \Drupal\campaign_kit_core\Entity\CampaignTransaction
   *   Returns a Campaign Transaction.
   */
  public function createCampaignTransaction(array $values = []) {
    // Create Campaign Transaction entity.
    /* @var $campaignTransaction \Drupal\campaign_kit_core\Entity\CampaignTransaction */
    $campaignTransaction = CampaignTransaction::create($values);

    return $campaignTransaction;
  }

  /**
   * Add conditions to a view.
   *
   * @param $query
   * @param $fieldName
   * @param $lowestAmount
   * @param $highestAmount
   */
  public function alterExposedForm(&$query, $fieldName, $lowestAmount, $highestAmount){
    if (isset($lowestAmount) && $lowestAmount != 0) {
      $query->where[0]['conditions'][4]['field'] = $fieldName . '.amount';
      $query->where[0]['conditions'][4]['value'] = (int) $lowestAmount;
      $query->where[0]['conditions'][4]['operator'] = '>=';
    }

    if (isset($highestAmount) && $highestAmount != 0) {
      $query->where[0]['conditions'][5]['field'] = $fieldName . '.amount';
      $query->where[0]['conditions'][5]['value'] = (int) $highestAmount;
      $query->where[0]['conditions'][5]['operator'] = '<=';
    }
  }

}
